@@ -6,14 +6,13 @@
 #define _WG_NOISE_H
 
 #include "messages.h"
-#include "hashtables.h"
+#include "peerlookup.h"
 
 #include <linux/types.h>
 #include <linux/spinlock.h>
 #include <linux/atomic.h>
 #include <linux/rwsem.h>
 #include <linux/mutex.h>
-#include <linux/ktime.h>
 #include <linux/kref.h>
 
 union noise_counter {
